@@ -444,7 +444,7 @@ def plot_infrared_func(user_args):
     )
 
     freqs = next((x for x in f_extractor), None)[1]
-    ints = next((x for x in i_extractor), None)[1]
+    ints = next((x for x in i_extractor), None)[1] * 100/np.log(10)
 
     f_range = np.linspace(
         user_args.min_energy,
