@@ -440,7 +440,7 @@ def create_title_and_route(method, extra_radii, opt=True, freq=True, ecp=False,
 
     if freq:
         title += "FREQ "
-        routecard += "freq=HPModes iop(7/33=3) "
+        routecard += "freq=(HPModes, SaveNormalModes) iop(7/33=3) "
 
     routecard += " {} ".format(method_name)
 
